

RegistryQuery
===============================

.. currentmodule:: pyvo.registry.vao

.. autoclass:: RegistryQuery
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~RegistryQuery.ALLOWED_CAPS
      ~RegistryQuery.ALLOWED_WAVEBANDS
      ~RegistryQuery.RESULTSET_TYPE_ARG
      ~RegistryQuery.SERVICE_NAME
      ~RegistryQuery.WAVEBAND_SYN
      ~RegistryQuery.keywords
      ~RegistryQuery.predicates
      ~RegistryQuery.servicetype
      ~RegistryQuery.waveband

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~RegistryQuery.addkeywords
      ~RegistryQuery.addpredicate
      ~RegistryQuery.clearkeywords
      ~RegistryQuery.clearpredicates
      ~RegistryQuery.execute
      ~RegistryQuery.execute_stream
      ~RegistryQuery.execute_votable
      ~RegistryQuery.getqueryurl
      ~RegistryQuery.keywords_to_predicate
      ~RegistryQuery.or_keywords
      ~RegistryQuery.removekeywords
      ~RegistryQuery.removepredicate
      ~RegistryQuery.will_or_keywords

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: ALLOWED_CAPS
   .. autoattribute:: ALLOWED_WAVEBANDS
   .. autoattribute:: RESULTSET_TYPE_ARG
   .. autoattribute:: SERVICE_NAME
   .. autoattribute:: WAVEBAND_SYN
   .. autoattribute:: keywords
   .. autoattribute:: predicates
   .. autoattribute:: servicetype
   .. autoattribute:: waveband

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: addkeywords
   .. automethod:: addpredicate
   .. automethod:: clearkeywords
   .. automethod:: clearpredicates
   .. automethod:: execute
   .. automethod:: execute_stream
   .. automethod:: execute_votable
   .. automethod:: getqueryurl
   .. automethod:: keywords_to_predicate
   .. automethod:: or_keywords
   .. automethod:: removekeywords
   .. automethod:: removepredicate
   .. automethod:: will_or_keywords

   
   